* tests/core/other/var.cc,
* tests/histo/compute.cc,
* tests/histo/to_image1d.cc: rename here.
---
milena/ChangeLog | 8 ++++++++
milena/tests/core/other/var.cc | 6 +++---
milena/tests/histo/compute.cc | 14 +++++++-------
milena/tests/histo/to_image1d.cc | 8 ++++----
4 files changed, 22 insertions(+), 14 deletions(-)
diff --git a/milena/ChangeLog b/milena/ChangeLog
index 8201593..f059029 100644
--- a/milena/ChangeLog
+++ b/milena/ChangeLog
@@ -1,5 +1,13 @@
2009-01-19 Guillaume Lazzara <z(a)lrde.epita.fr>
+ Rename histo::data as histo::array.
+
+ * tests/core/other/var.cc,
+ * tests/histo/compute.cc,
+ * tests/histo/to_image1d.cc: rename here.
+
+2009-01-19 Guillaume Lazzara <z(a)lrde.epita.fr>
+
Improve soft heap interface.
* mln/util/soft_heap.hh: rename take() as push().
diff --git a/milena/tests/core/other/var.cc b/milena/tests/core/other/var.cc
index 6079142..1fd8dfc 100644
--- a/milena/tests/core/other/var.cc
+++ b/milena/tests/core/other/var.cc
@@ -33,7 +33,7 @@
#include <mln/core/image/image2d.hh>
#include <mln/core/alias/window2d.hh>
#include <mln/core/alias/neighb2d.hh>
-#include <mln/histo/data.hh>
+#include <mln/histo/array.hh>
#include <mln/util/array.hh>
#include <mln/core/var.hh>
@@ -73,7 +73,7 @@ void test_template()
mln_BKD_EITER(e, arr);
}
- histo::data<bool> d;
+ histo::array<bool> d;
{
mln_VITER(v, d.vset());
}
@@ -120,7 +120,7 @@ void test()
mln_BKD_EITER_(e, arr);
}
- histo::data<bool> d;
+ histo::array<bool> d;
{
mln_VITER_(v, d.vset());
}
diff --git a/milena/tests/histo/compute.cc b/milena/tests/histo/compute.cc
index f2bc569..f00d7d2 100644
--- a/milena/tests/histo/compute.cc
+++ b/milena/tests/histo/compute.cc
@@ -1,4 +1,5 @@
-// Copyright (C) 2007, 2008 EPITA Research and Development Laboratory
+// Copyright (C) 2007, 2008, 2009 EPITA Research and Development
+// Laboratory (LRDE)
//
// This file is part of the Olena Library. This library is free
// software; you can redistribute it and/or modify it under the terms
@@ -25,10 +26,9 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
/*! \file tests/histo/compute.cc
*
* \brief Tests on mln::accu::histo and mln::histo::data.
*/
#include <iterator>
#include <sstream>
@@ -70,7 +70,7 @@ int main()
debug::iota(ima);
opt::at(ima, 0,0) = 2;
- histo::data<int_u8> h = histo::compute(ima);
+ histo::array<int_u8> h = histo::compute(ima);
std::ostringstream oss;
oss << h;
mln_assertion(oss.str() == "2:2 3:1 4:1 5:1 6:1 7:1 8:1 9:1 ");
@@ -86,7 +86,7 @@ int main()
image2d<int_s5> ima(3, 3);
debug::iota(ima);
- histo::data<int_s5> h = histo::compute(ima);
+ histo::array<int_s5> h = histo::compute(ima);
mln_assertion(h.vset().nvalues() == 31);
for (unsigned i = 0; i <= 15; ++i) // values from -15 to 0
@@ -25,10 +26,9 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-/*! \file tests/histo/compute.cc
- *
- * \brief Tests on mln::accu::histo and mln::histo::data.
- */
+/// \file tests/histo/compute.cc
+///
+/// Tests on mln::accu::histo and mln::histo::array.
#include <iterator>
#include <sstream>
diff --git a/milena/tests/histo/to_image1d.cc b/milena/tests/histo/to_image1d.cc
index ee09b85..aad3c99 100644
--- a/milena/tests/histo/to_image1d.cc
+++ b/milena/tests/histo/to_image1d.cc
@@ -1,5 +1,5 @@
-// Copyright (C) 2007, 2008 EPITA Research and Development Laboratory
-// (LRDE
+// Copyright (C) 2007, 2008, 2009 EPITA Research and Development
+// Laboratory (LRDE)
//
// This file is part of the Olena Library. This library is free
// software; you can redistribute it and/or modify it under the terms
@@ -28,7 +28,7 @@
/// \file tests/histo/to_image1d.cc
///
/// Tests on mln::accu::histo and mln::histo::data.
#include <iterator>
@@ -68,7 +68,7 @@ int main()
debug::iota(ima);
ima(point2d(0,1)) = 255;
debug::println(ima);
- histo::data<int_u8> h = histo::compute(ima);
+ histo::array<int_u8> h = histo::compute(ima);
std::cout << h << std::endl;
image1d<unsigned> ima2 = convert::to_image(h);
@@ -28,7 +28,7 @@
/// \file tests/histo/to_image1d.cc
///
-/// Tests on mln::accu::histo and mln::histo::data.
+/// Tests on mln::accu::histo and mln::histo::array.
#include <iterator>
--
1.5.6.5